diff bns_website/bands/tests/view_tests.py @ 39:b9d6f6d930a9

Merged Chris and Brian's changes with mine.
author Bob Mourlam <bob.mourlam@gmail.com>
date Sun, 06 Nov 2011 20:28:25 -0600
parents 5992b6b1bcd2
children
line wrap: on
line diff
--- a/bns_website/bands/tests/view_tests.py	Sun Nov 06 20:22:40 2011 -0600
+++ b/bns_website/bands/tests/view_tests.py	Sun Nov 06 20:28:25 2011 -0600
@@ -8,9 +8,9 @@
 
 class ViewTest(TestCase):
 
-    def test_home(self):
+    def test_bands(self):
         """
         Tests the home page to ensure it displays without errors.
 
         """
         response = self.client.get(reverse('bands'))
@@ -8,9 +8,9 @@
         """
-        Tests the home page to ensure it displays without errors.
+        Tests the bands page to ensure it displays without errors.
 
         """